.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   Installation <install>
   Usage <usage>
   Adapters <adapters>
   Creating a new adapter <development>
   Postgres backend <postgres>
   Sqlglot backend <sqlglot>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
